pub enum Error<E> {
Show 13 variants
Generic(&'static str),
IO(E),
NotExFAT,
Checksum,
EOF,
NoSpace,
BadCluster(ClusterID),
TexFATNotSupported,
UpcaseTableMissing,
UpcaseTableChecksum,
AllocationBitmapMissing,
NoSuchFileOrDirectory,
AlreadyOpen,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.