pub struct ExFAT<IO> { /* private fields */ }Implementations
Sourceimpl<B: Deref<Target = [Block]>, E: Debug, IO> ExFAT<IO>where
IO: IO<Block<'static> = B, Error = E>,
impl<B: Deref<Target = [Block]>, E: Debug, IO> ExFAT<IO>where
IO: IO<Block<'static> = B, Error = E>,
pub fn new(io: IO) -> Result<Self, Error<E>>
pub fn is_dirty(&mut self) -> Result<bool, Error<E>>
pub fn percent_inuse(&mut self) -> Result<u8, Error<E>>
pub fn set_dirty(&mut self, dirty: bool) -> Result<(), Error<E>>
pub fn validate_checksum(&mut self) -> Result<(), Error<E>>
pub fn serial_number(&self) -> u32
Sourcepub fn root_directory(&mut self) -> Result<Root<B, E, IO>, Error<E>>
pub fn root_directory(&mut self) -> Result<Root<B, E, IO>, Error<E>>
Cluster usage is calculated by default, which is inaccurate, therefore you may encounter
false allocation failure when still some clusters available.
For precise cluster usage calculation, you may call update_usage which will cost some time.
pub fn try_free(self) -> Result<IO, Self>