Crate exfat

source ·
embedded-exfat

An ExFAT Library in rust mainly focusing on no_std embedded system with async support

alloc is mandatory for this crate, although memory allocation is minimized, 256B for Allocation bitmap and 12B for each file or directory, including root directory.

Modules

Macros

Structs

Enums