Struct exfat::file::FileOptions
source · pub struct FileOptions {
pub dont_fragment: bool,
}Fields
dont_fragment: boolFragment will produce unpredictable latency when writing, enabling this option will indicate write operation returns Fragment error instead of filling FAT chain